/**
 * ConfigurationPanel
 *   Presents choices needed to enable/disable various features of NaviKey
 *   Intended to be incorporated in the main NaviKey UI
 * @author Michael Bartley
 * @date 7/1/99
 * @author Dieter Neubacher
*/

package net.metadiversity.diversity.navikey.ui;

import javax.swing.JPanel;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JLabel;

class ConfigurationPanel extends javax.swing.JPanel
{
    /**
     * Comment for <code>serialVersionUID</code>
     */
    private static final long serialVersionUID = 4051049644454720816L;
    private JCheckBox   useBestAlgorithm;
    private JCheckBox   useCharacterDependencies;
    private JCheckBox   smartsbox;
    private JCheckBox   excludeUndefined;
    private JCheckBox   multipleSelectionAndOr;
    private JCheckBox   extremeInterval;
    private JCheckBox   overlappingInterval;
    private JButton     infobutton;

    private java.awt.event.ActionListener navikeyGuiListener;
    
    public ConfigurationPanel()
    {
        super();
     
        setLayout( new java.awt.BorderLayout() );
        // 
        JLabel label = new JLabel( "NaviKey options: " );
        label.setVerticalAlignment( javax.swing.SwingConstants.TOP );
        
        useBestAlgorithm = new JCheckBox( "Use \"Best\" algorithm (To be implemented)");
        useBestAlgorithm.setEnabled( false );
        useCharacterDependencies = new JCheckBox( "Use character dependencies (To be implemented)");
        useCharacterDependencies.setEnabled( false );
        
        smartsbox = new JCheckBox( "Restrict view on used characters and character states of remaining items" );
        smartsbox.setSelected( NaviKey.isIntelligence()  );
        
        smartsbox.addActionListener(new java.awt.event.ActionListener()
        {
            public void actionPerformed(java.awt.event.ActionEvent evt)
            {
                smartsBoxActionPerformed( evt );
            }
        });
        // Don't evaluate undefind CharacterStates
        excludeUndefined = new JCheckBox( "Exclude items with undefined states in selected characters" );
        excludeUndefined.setSelected( NaviKey.isExcludeUndefined()  );
        
        excludeUndefined.addActionListener(new java.awt.event.ActionListener()
        {
            public void actionPerformed(java.awt.event.ActionEvent evt)
            {
                excludeUndefinedActionPerformed( evt );
            }
        });
        // Multiple State selection with AND / OR
        multipleSelectionAndOr = new JCheckBox( "Enable multiple selection of character states (with OR)" );
        multipleSelectionAndOr.setSelected( NaviKey.isMultipleSelectionOR()  );
        
        multipleSelectionAndOr.addActionListener(new java.awt.event.ActionListener()
        {
            public void actionPerformed(java.awt.event.ActionEvent evt)
            {
                multipleSelectionAndOrActionPerformed( evt );
            }
        });
        // extreme interval validation
        extremeInterval = new JCheckBox( "Use extreme interval validation" );
        extremeInterval.setSelected( NaviKey.isExtremeInterval()  );
        
        extremeInterval.addActionListener(new java.awt.event.ActionListener()
        {
            public void actionPerformed(java.awt.event.ActionEvent evt)
            {
                extremeIntervalActionPerformed( evt );
            }
        });
        // overlapping interval vaidation
        overlappingInterval = new JCheckBox( "Use overlapping interval validation" );
        overlappingInterval.setSelected( NaviKey.isOverlappingInterval()  );
        
        overlappingInterval.addActionListener(new java.awt.event.ActionListener()
        {
            public void actionPerformed(java.awt.event.ActionEvent evt)
            {
                overlappingIntervalActionPerformed( evt );
            }
        });
        // Show "About" Window
        infobutton = new JButton( "About NaviKey" );        
        infobutton.addActionListener(new java.awt.event.ActionListener()
        {
            public void actionPerformed(java.awt.event.ActionEvent evt)
            {
                infoButtonActionPerformed( evt );
            }
        });
        
        JPanel optspanel = new JPanel();
        optspanel.setLayout( new java.awt.GridLayout( 7, 1 ) );
        optspanel.add( useBestAlgorithm );
        optspanel.add( useCharacterDependencies );
        optspanel.add( smartsbox );
        optspanel.add( excludeUndefined );
        optspanel.add( multipleSelectionAndOr );
        optspanel.add( extremeInterval  );
        optspanel.add( overlappingInterval );
        
        add( java.awt.BorderLayout.WEST,    label       );
        add( java.awt.BorderLayout.CENTER,  optspanel   );
        add( java.awt.BorderLayout.EAST,    infobutton  );
        
        setVisible( true );
    }
    //--------------------------------------------------------------------------
    //--------------------------------------------------------------------------
    private void infoButtonActionPerformed( java.awt.event.ActionEvent evt )
    {
        System.out.println( "Info about NaviKey:" );        
        
        InfoFrame inf = new InfoFrame();
        inf.setSize( 500,450 );
        inf.setVisible( true );
    }
    //--------------------------------------------------------------------------
    //--------------------------------------------------------------------------
    private void smartsBoxActionPerformed( java.awt.event.ActionEvent evt )
    {
        boolean old = smartsbox.isSelected(); 
        NaviKey.setIntelligence( ( old ? true : false ) );
        
        java.awt.event.ActionEvent ae = new java.awt.event.ActionEvent( this, 1, "OptionsChanged" );        
        navikeyGuiListener.actionPerformed( ae );        
    }
    //--------------------------------------------------------------------------
    //--------------------------------------------------------------------------
    private void excludeUndefinedActionPerformed( java.awt.event.ActionEvent evt )
    {
        boolean old = excludeUndefined.isSelected(); 
        NaviKey.setExcludeUndefined( ( old ? true : false ) );
        
        java.awt.event.ActionEvent ae = new java.awt.event.ActionEvent( this, 1, "OptionsChanged" );        
        navikeyGuiListener.actionPerformed( ae );        
    }
    //--------------------------------------------------------------------------
    //--------------------------------------------------------------------------    
    private void multipleSelectionAndOrActionPerformed( java.awt.event.ActionEvent evt )
    {
        boolean old = multipleSelectionAndOr.isSelected(); 
        NaviKey.setMultipleSelectionOR( ( old ? true : false ) );
        
        java.awt.event.ActionEvent ae = new java.awt.event.ActionEvent( this, 1, "OptionsChanged" );        
        navikeyGuiListener.actionPerformed( ae );        
    }
    //--------------------------------------------------------------------------
    //--------------------------------------------------------------------------    
    private void extremeIntervalActionPerformed( java.awt.event.ActionEvent evt )
    {
        boolean old = extremeInterval.isSelected(); 
        NaviKey.setExtremeInterval( ( old ? true : false ) );
        
        java.awt.event.ActionEvent ae = new java.awt.event.ActionEvent( this, 1, "OptionsChanged" );        
        navikeyGuiListener.actionPerformed( ae );        
    }

    //--------------------------------------------------------------------------
    //--------------------------------------------------------------------------    
    private void overlappingIntervalActionPerformed( java.awt.event.ActionEvent evt )
    {
        boolean old = overlappingInterval.isSelected(); 
        NaviKey.setOverlappingInterval( ( old ? true : false ) );
        
        java.awt.event.ActionEvent ae = new java.awt.event.ActionEvent( this, 1, "OptionsChanged" );        
        navikeyGuiListener.actionPerformed( ae );        
    }
            /* ???
    public void setForeground( Color c )
    {
        smartsbox.setForeground( c );
        infobutton.setForeground( c );
        super.setForeground( c );
    }
    
    public void setBackground( Color c )
    {
        smartsbox.setBackground( c );
        infobutton.setBackground( c );
        super.setBackground( c );
    }
    */

    /*
    public boolean processEvent( Event e )
    {
        if( e.target == smartsbox )
        {
            if( e.id == Event.ACTION_EVENT )
            {
                boolean old = ( ( JCheckBox )e.target ).isSelected(); 
                NaviKey.intelligence = ( old ? true : false );
            }
        }
        else if( e.target == infobutton )
        {
            if( e.id == Event.ACTION_EVENT )
            {
                InfoFrame inf = new InfoFrame();
                inf.setSize( 500,450 );
                inf.setVisible( true );
                System.out.println( "Info about NaviKey:" );
            }
        }
        return super.processEvent( e );
    }
    */
    //--------------------------------------------------------------------------    
    //--------------------------------------------------------------------------        
    public void addNavikeyGuiListener( java.awt.event.ActionListener al )
    {
        navikeyGuiListener = al;
    }    
    
}
